@@ -1,5 +1,5 @@
 from .checks import check_field_access
-from .django_to_pydantic import transfer_from_orm
+from .django_to_pydantic import transfer_from_orm, transfer_current_obj as transfer_from_orm_current_obj
 from .pydantic_to_django import transfer_to_orm, TransferAction, update_orm
 from .pydantic import DjangoORMBaseModel, validate_object, orm_object_validator
 from .utils import dict_resolve_obj_to_id
